cosmpy.protos.cosmos.base.reflection.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.base.reflection.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.base.reflection.v1beta1.reflection_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.base.reflection.v1beta1.reflection_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.base.reflection.v1beta1.reflection_pb2_grpc.ReflectionService

  Bases: `object`

  ReflectionService defines a service for interface reflection.

  static ListAllInterfaces(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ListImplementations(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.base.reflection.v1beta1.reflection_pb2_grpc.ReflectionServiceServicer

  Bases: `object`

  ReflectionService defines a service for interface reflection.

  ListAllInterfaces(request, context)

    ListAllInterfaces lists all the interfaces registered in the interface registry.

  ListImplementations(request, context)

    ListImplementations list all the concrete types that implement a given interface.

class cosmpy.protos.cosmos.base.reflection.v1beta1.reflection_pb2_grpc.ReflectionServiceStub(channel)

  Bases: `object`

  ReflectionService defines a service for interface reflection.

cosmpy.protos.cosmos.base.reflection.v1beta1.reflection_pb2_grpc.add_ReflectionServiceServicer_to_server(servicer, server)

## Module contents